"""
Exemple de résolution d'équations différentielles :
équation d'ordre 1 : dv/dt + v/tau = B/tau
"""

from matplotlib.widgets import Cursor
from scipy import *
from pylab import *
from scipy.integrate import odeint      # Module de résolution des équations différentielles

# Coefficients et conditions initiales

r = float(input("entrer la valeur du rayon (en m):    "))
rho = float(input("entrer la valeur de la masse volumique de la bille (en kg/m3):    "))
rho0 = float(input("entrer la valeur de la masse volumique de la glycérine (en kg/m3):    "))
n = float(input("entrer un multiple de tau:..."))
v0 = 0
V = 4.19*r**3
m = rho*V*9.8

# calcul de tau theorique
def calculTau(m,r):
    tau = m/(279*r)       
    return tau

tau=calculTau(m,r)
print("Valeur de tau :",round(tau,5), " s")
Fin=n*tau

A = tau*9.8*(1-rho0/rho)

# Création des valeurs de dérivée
def deriv(syst, t):
    y = syst[0]                         # Variable y(t) ici v(t)
    dydt=-y/tau + A/tau                # Equation différentielle
    return [dydt]                       # Dérivées des variables

# Paramètres d'intégration
start = 0
end = Fin
numsteps = 200
t = linspace(start,end,numsteps)

# Résolution
y0=v0
syst_CI=array([y0])                     # Tableau des CI
Sols=odeint(deriv,syst_CI,t)            # Résolution numérique de l'équation différentielle

# Récupération des solutions
y = Sols[:, 0]

# Graphique
fig=subplot()
plot ( t , y, 'b-*', linewidth=1,  label="Chute d'une bille")
grid()
xlabel("t (s)", fontsize=16)            # Label de l'axe des abscisses
ylabel("Vitesse en m/s", fontsize=16)           # Label de l'axe des ordonnées
legend(loc = 'best')

# curseur pour lire une valeur
Cursor(fig, useblit=True, color='red', linewidth=1)
show()



